@@ -21,19 +21,19 @@
 
 /**
  * SECTION:element-autoaudiosrc
+ * @title: autoaudiosrc
  * @see_also: autovideosrc, alsasrc, osssrc
  *
  * autoaudiosrc is an audio source that automatically detects an appropriate
  * audio source to use.  It does so by scanning the registry for all elements
- * that have <quote>Source</quote> and <quote>Audio</quote> in the class field
+ * that have "Source" and "Audio" in the class field
  * of their element information, and also have a non-zero autoplugging rank.
  *
- * <refsect2>
- * <title>Example launch line</title>
+ * ## Example launch line
  * |[
  * gst-launch-1.0 -v -m autoaudiosrc ! audioconvert ! audioresample ! autoaudiosink
  * ]|
- * </refsect2>
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -75,8 +75,7 @@ gst_auto_audio_src_class_init (GstAutoAudioSrcClass * klass)
   GstAutoDetectClass *autoclass = GST_AUTO_DETECT_CLASS (klass);
   GstElementClass *eklass = GST_ELEMENT_CLASS (klass);
 
-  gst_element_class_add_pad_template (eklass,
-      gst_static_pad_template_get (&src_template));
+  gst_element_class_add_static_pad_template (eklass, &src_template);
   gst_element_class_set_static_metadata (eklass, "Auto audio source",
       "Source/Audio",
       "Wrapper audio source for automatically detected audio source",
