@@ -76,7 +76,7 @@ GType gst_v4l2_video_dec_get_type (void);
 gboolean gst_v4l2_is_video_dec       (GstCaps * sink_caps, GstCaps * src_caps);
 void     gst_v4l2_video_dec_register (GstPlugin * plugin,
                                       const gchar *basename,
-                                      const gchar *device_path,
+                                      const gchar *device_path, gint video_fd,
                                       GstCaps * sink_caps, GstCaps * src_caps);
 
 G_END_DECLS
